package com.boylesoftware.cb2;

import com.boylesoftware.cb2.util.pool.PooledObjectFactoryAdapter;
import com.boylesoftware.cb2.util.pool.AdaptiveObjectPool;


/**
 * Factory for <code>ActiveConnection</code> objects.
 *
 * @author Lev Himmelfarb
 * @version $Id: ActiveConnectionFactory.java,v 1.2 2004/04/02 21:30:46 levahim Exp $
 */
class ActiveConnectionFactory
    extends PooledObjectFactoryAdapter {

    /**
     * Reference to our application context.
     */
    private final ApplicationContext appCtx;

    /**
     * Centralized pool of <code>ActiveStatement</code> objects so we don't
     * have a pool in each <code>ActiveConnection</code> instance.
     */
    private final AdaptiveObjectPool stmtPool;


    /**
     * Creates a factory.
     *
     * @param appCtx reference to our application context.
     */
    ActiveConnectionFactory(ApplicationContext appCtx) {

        this.appCtx = appCtx;
        this.stmtPool =
            new AdaptiveObjectPool(new ActiveStatementFactory(appCtx));
    }


    /**
     * Create an instance of <code>ActiveConnection</code>.
     *
     * @return a new instance of <code>ActiveConnection</code>.
     */
    public Object createObject() {

        return new ActiveConnection(this.pool,
                                    this.appCtx,
                                    this.stmtPool);
    }
}
