package com.boylesoftware.cb2;

import java.io.StringWriter;
import java.io.PrintWriter;
import java.sql.SQLException;
import javax.naming.NamingException;


/**
 * CB2 exception generated on the application context level. All exceptions in
 * CB2, most notably <code>BLException</code> and subclasses, extend this
 * generic application exception class. Applications can have their own
 * specific subclasses of <code>ApplicationException</code> for errors that
 * happen somewhere outside the Business Level, usually some really low-level
 * errors, but such a need arises very rarely. Usually, you extend
 * <code>BLException</code> instead.
 *
 * @author Lev Himmelfarb
 * @version $Id: ApplicationException.java,v 1.2 2004/04/16 21:43:27 levahim Exp $
 */
public class ApplicationException
    extends Exception {

    /**
     * Constructs a new exception with an error message.
     *
     * @param message the error description.
     */
    public ApplicationException(String message) {
        super(message);
    }

    /**
     * Constructs a new exception with an error message and a throwable, which
     * is the root cause of this error.
     *
     * @param message the error description.
     * @param cause the original cause of this exception.
     */
    public ApplicationException(String message, Throwable cause) {
        super(message, cause);
    }

    /**
     * Gets string representation of this exception's description including
     * verbose description of its cause with the stack trace.
     *
     * @return the exception's verbose desription.
     */
    public String toString() {
        StringBuffer res = new StringBuffer();

        res.append(super.toString());
        if(this.getCause() != null) {
            res.append("\n--- BEGIN ROOT CAUSE ---\n");

            Throwable cause = this.getCause();

            res.append("EXCEPTION:  ");
            res.append(cause.getClass().getName());
            res.append("\n");

            res.append("MESSAGE:    ");
            res.append(cause.getMessage());
            res.append("\n");

            if(cause instanceof SQLException) {
                SQLException sqlCause = (SQLException)cause;

                res.append("ERROR CODE: ");
                res.append(sqlCause.getErrorCode());
                res.append("\n");

                res.append("SQL STATE:  ");
                res.append(sqlCause.getSQLState());
                res.append("\n");

            } else if(cause instanceof NamingException) {
                NamingException namingCause = (NamingException)cause;

                if(namingCause.getExplanation() != null) {
                    res.append("DETAILS:    ");
                    res.append(namingCause.getExplanation());
                    res.append("\n");
                }

                if(namingCause.getRootCause() != null) {
                    res.append("CAUSE:      ");
                    res.append(namingCause.getRootCause().getClass().getName());
                    res.append(": ");
                    res.append(namingCause.getRootCause().getMessage());
                    res.append("\n");
                }
            }

            res.append("STACK:      ");
            StringWriter sw = new StringWriter();
            PrintWriter pw = new PrintWriter(sw);
            cause.printStackTrace(pw);
            pw.flush();
            pw.close();
            res.append(sw.toString());
            res.append("--- END ROOT CAUSE ---\n");
        }

        return res.toString();
    }
}
