package com.boylesoftware.cb2;

import java.security.Principal;


/**
 * BLOs can implement this interface if they want to be notified about
 * user logins and logouts. When a BLO container is notified about a
 * user login or logout through its <code>processUserLogin</code> and
 * <code>processUserLogout</code> methods it goes through all its BLOs
 * that implement this interface and calls appropriate methods on
 * them.
 *
 * <p>The BLO container starts a transaction when it calls methods of this
 * interface. If you have multiple BLOs implementing the interface, all BLOs
 * are called within one single transaction.
 *
 * <p>When a BLO container is being destroyed, usually because the
 * corresponding user session finishes or the whole application goes down, and
 * there is a user authenticated for the session, the container "forces" user
 * logout and notifies all authentication listeners about it first, and only
 * then goes down.
 *
 * <p>Since it does not correspond to any user session, the Shared BLO
 * Container does not get notified about user login/logout events. It means
 * that there is little sense in implementing this interface by a shared BLO.
 *
 * <p>Warning! Because of internal library resources access synchronization,
 * never call <code>getUserPrincipal</code> on the BLO container from any of
 * this interface's methods! It will stall the whole application.
 *
 * @author Lev Himmelfarb
 * @version $Id: AuthenticationListener.java,v 1.2 2004/04/16 21:43:27 levahim Exp $
 */
public interface AuthenticationListener {

    /**
     * Notify the BLO about a user login event.
     *
     * @param principal the logged in principal.
     *
     * @throws BLException if an error happened and the user cannot be
     * logged in.
     */
    void processUserLogin(Principal principal)
        throws BLException;

    /**
     * Notify the BLO about a user logout event.
     *
     * @throws BLException if an error happened and the user cannot be
     * logged out.
     */
    void processUserLogout()
        throws BLException;
}
