package com.boylesoftware.cb2;

import java.util.EventListener;
import java.io.Serializable;


/**
 * CB2 Broadcast Messaging clients (the BCM terminals) implement this interface
 * and register within the application context under specific BCM channel names
 * to receive broadcast messages.
 *
 * @author Lev Himmelfarb
 * @version $Id: BroadcastMessagingTerminal.java,v 1.3 2004/04/16 21:43:27 levahim Exp $
 *
 * @see ApplicationContext#registerBCMTerminal
 */
public interface BroadcastMessagingTerminal
    extends EventListener {

    /**
     * This method gets called when a message is received.
     *
     * <p>The method should be written thread-safe, because the framework may
     * let multiple threads into this method at the same time.
     *
     * @param channelName name of the BCM channel, on which the message was
     * received.
     * @param source a string, which identifies in a specific to the BCM
     * provider implementation way the JVM that sent the message.
     * @param messageParam optional general purpose parameter sent along with
     * the message, may be <code>null</code>.
     *
     * @throws ApplicationException if the was a serious error during the
     * message processing. This exception goes directly to the BCM provider,
     * which called application context's <code>processBCMMessage</code>
     * method to deliver the message to the terminal.
     */
    void processMessage(String channelName,
                        String source,
                        Serializable messageParam)
        throws ApplicationException;
}
