package com.boylesoftware.cb2;


/**
 * Common parent interface for various DAO plugin subinterfaces. You cannot
 * write a plugin, which implements only this interface - it is abstract.
 * Instead, a plugin implementation must implement one or more of the derived
 * from this definition subinterfaces. Depending on what particular
 * subinterfaces your plugin implements, the DAO will be calling its methods at
 * certain moments to perform certain elementary operations.
 *
 * <p>To install a plugin add a <code>&lt;plugin&gt;</code> element into your
 * DAO configuration in the <code>blo-config.xml</code> file:
 *
 * <pre>
 * &lt;plugin&gt;
 *   &lt;class&gt;org.myorganization.myapplication.MyDAOPluginImplementation&lt;/class&gt;
 * &lt;/plugin&gt;</pre>
 *
 * <p>Note, that some subinterfaces allow to have multiple plugins implementing
 * them installed on a DAO, while others allow only one single plugin of that
 * type for a DAO.
 *
 * @author Lev Himmelfarb
 * @version $Id: DAOPlugin.java,v 1.3 2004/04/20 16:00:58 levahim Exp $
 *
 * @see DAO
 */
public interface DAOPlugin {

    /**
     * The systems calls this method after it creates a new instance of the
     * plugin, once in its lifecycle.
     *
     * @param appCtx the application context.
     */
    public void setApplicationContext(ApplicationContext appCtx);
}
