package com.boylesoftware.cb2;


/**
 * Descriptor or a result set processed by a DAO fetch call. An instance of
 * this class can be passed to certain DAO fetch methods and after the method
 * returns, the instance will contain additional information about the result
 * set. This works only when a paginated result is requested and allows to find
 * out such information as how many rows there were in the whole result set,
 * not only the requested page.
 *
 * @author Lev Himmelfarb
 * @version $Id: FetchResultDescriptor.java,v 1.4 2004/10/11 18:17:36 levahim Exp $
 *
 * @see DAO#fetch(String, java.util.Set, Object [], String [], int, int, int, FetchResultProcessorHandler [], FetchResultDescriptor)
 * @see DAO#executeFetch(Class, String, Object [], int, int, FetchResultProcessorHandler [], FetchResultDescriptor)
 */
public final class FetchResultDescriptor
    implements java.io.Serializable {

    /**
     * Total number of rows in the result set.
     */
    private int rowsTotal;


    /**
     * Gets total number of rows in the result set, not only in the requested
     * page,
     *
     * @return total number of rows in the result set.
     */
    public int getRowsTotal() {

        return this.rowsTotal;
    }

    /**
     * Sets the <code>rowsTotal</code> property. Can be used from within DAO
     * plugins, namely a <code>FetchExecutor</code> plugin.
     *
     * @param rowsTotal new value for <code>rowsTotal</code>.
     */
    public void setRowsTotal(int rowsTotal) {

        this.rowsTotal = rowsTotal;
    }
}
