package com.boylesoftware.cb2;

import java.sql.ResultSet;
import java.sql.SQLException;


/**
 * Interface for the DAO plugin, which is responsible for getting column values
 * from the result set during a DAO fetch call. The DAO calls this plugin
 * whenever it needs a column's value from a result set to be set into a DM.
 *
 * <p>Only one plugin of this type can be installed in a DAO configuration.
 * If none installed, the DAO will use a simple internal implementation, which
 * calls <code>getObject</code> on the <code>java.sql.ResultSet</code>.
 *
 * <p>Note, that one instance of the plugin can be shared by multiple threads
 * at the same time.
 *
 * @author Lev Himmelfarb
 * @version $Id: ResultSetFieldGetter.java,v 1.3 2004/05/12 15:41:17 levahim Exp $
 */
public interface ResultSetFieldGetter
    extends DAOPlugin {

    /**
     * Gets the specified column's value from the result set.
     *
     * @param rs the result set.
     * @param columnIndex the column index.
     * @param dmFieldName name of the target DM field.
     * @param dmFieldClass type of the target DM field. When the DM is a
     * <code>DynamicDataModel</code>, generic <code>Object</code> class is
     * passed from the DAO.
     *
     * @return value to be put into the DM field, can return <code>null</code>.
     *
     * @throws SQLException if an error happens.
     */
    public Object getResultSetField(ResultSet rs,
                                    int columnIndex,
                                    String dmFieldName,
                                    Class dmFieldClass)
        throws SQLException;
}
