package com.boylesoftware.cb2;

import java.sql.Connection;

import com.boylesoftware.cb2.util.sql.ConnectionWrapper;


/**
 * Implementation of JDBC's <code>Connection</code> interface that
 * wraps a real connection object and links it with a specific
 * transaction context. This class overrides some of the original
 * interface methods, disallowing transaction management methods and also
 * "skips" closing the connection.
 *
 * @author Lev Himmelfarb
 * @version $Id: TxConnection.java,v 1.2 2004/10/11 18:17:36 levahim Exp $ 
 */
final class TxConnection
    extends ConnectionWrapper {

    /**
     * Creates a new wrapped connection object.
     *
     * @param con the connection to wrap.
     */
    TxConnection(Connection con) {
        super(con);
    }


    /**
     * Does nothing.
     */
    public void close() { /* do nothing */ }

    /**
     * Throws exception.
     */
    public void setAutoCommit(boolean autoCommit) {

        throw new UnsupportedOperationException("Cannot call setAutoCommit on a transactional connection.");
    }

    /**
     * Throws exception.
     */
    public void commit() {

        throw new UnsupportedOperationException("Cannot call commit on a transactional connection.");
    }

    /**
     * Throws exception.
     */
    public void rollback() {

        throw new UnsupportedOperationException("Cannot call rollback on a transactional connection.");
    }
}
