package com.boylesoftware.cb2.admin.servlet;

import java.io.Serializable;
import java.util.Date;


/**
 * <code>ClusterController</code> uses instances of this class for
 * info requests and responses as BCM message parameter.
 *
 * @author Lev Himmelfarb
 * @version $Id: ClusterControllerMessage.java,v 1.3 2003/10/28 22:23:19 levahim Exp $
 */
class ClusterControllerMessage
    implements Serializable {

    /**
     * Request key used to relate responses to a particular request.
     */
    public final String key;

    /**
     * Message type, one of <code>ClusterController.CR_xxx</code> codes.
     */
    public final int type;


    // Response info

    /**
     * Host name.
     */
    public String hostName;

    /**
     * Host IP address.
     */
    public String hostAddress;

    /**
     * URL of the admin servlet for the instance. Maybe <code>null</code>
     * if not determinable.
     */
    public String adminServletURL;

    /**
     * Current number of sessions.
     */
    public int nSessions;

    /**
     * Average number of requests per minute.
     */
    public long requestsPerMinute;

    /**
     * Timestamp when the instance was started.
     */
    public Date startedTs;

    /**
     * Number of errors.
     */
    public int nErrors;

    /**
     * Is the instance locked?
     */
    public boolean isLocked;


    /**
     * Constructs a new message object.
     *
     * @param key request key.
     * @param type the message type, one of
     * <code>ClusterController.CR_xxx</code> codes.
     */
    public ClusterControllerMessage(String key, int type) {

        this.key = key;
        this.type = type;
    }
}
