<!--
  - Stylesheet for DB Connection Pools page.
  -
  - author Lev Himmelfarb
  - version $Id: dbconpools.xsl,v 1.5 2004/05/10 15:47:00 levahim Exp $
 -->

<xsl:stylesheet
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  version="1.0">

  <xsl:output method="html" encoding="ISO-8859-1"/>

  <xsl:param name="timezone"/>

  <xsl:template match="/">
    <html>
      <head>
        <link rel="stylesheet" type="text/css" href="cb2-admin?disp=css"/>
      </head>
      <body class="content">
        <xsl:apply-templates/>
      </body>
    </html>
  </xsl:template>

  <xsl:template match="stats">
    <xsl:apply-templates select="db"/>
  </xsl:template>

  <xsl:template match="db">
    <div class="caption">Database Connection Pools<sup>*</sup></div>
    <xsl:apply-templates/>
    <div class="comment"><sup>*</sup> All times are in <xsl:value-of select="$timezone"/></div>
  </xsl:template>

  <xsl:template match="dataSource">
    <p><table class="params">
      <caption>DataSource: <xsl:value-of select="@name"/> - Parameters</caption>
      <tr>
        <th>param</th>
        <th>value</th>
      </tr>
      <xsl:apply-templates select="resinDBPool | commonsDBCP"/>
    </table></p>
    <p><span class="sectionTitle">DataSource: <xsl:value-of select="@name"/> - Get Connection Stats</span><br/>
    <table>
      <tr>
        <td><span class="sectionTitle">Last Hour</span><span class="special"> (actions per every 12 secs)</span></td>
        <td><span class="sectionTitle">Last 24 Hours</span><span class="special"> (actions per every 5 mins)</span></td>
      </tr>
      <tr>
        <td><img width="348" height="120"><xsl:attribute name="src">cb2-admin?disp=pic&amp;ss=appCtx&amp;name=DS_<xsl:value-of select="@name"/>_getConnection&amp;size=N&amp;ind=0</xsl:attribute></img></td>
        <td><img width="348" height="120"><xsl:attribute name="src">cb2-admin?disp=pic&amp;ss=appCtx&amp;name=DS_<xsl:value-of select="@name"/>_getConnection&amp;size=N&amp;ind=1</xsl:attribute></img></td>
      </tr>
    </table></p>
  </xsl:template>

  <xsl:template match="resinDBPool">
    <tr>
      <td class="paramName">Pool type</td>
      <td>Caucho Resin DB Connection Pool</td>
    </tr>
    <tr>
      <td class="paramName">The pool name</td>
      <td><xsl:value-of select="name"/></td>
    </tr>
    <tr>
      <td class="paramName">Driver</td>
      <td><xsl:value-of select="driverName"/></td>
    </tr>
    <tr>
      <td class="paramName">Database URL</td>
      <td><xsl:value-of select="url"/></td>
    </tr>
    <tr>
      <td class="paramName">Database user name</td>
      <td><xsl:value-of select="user"/></td>
    </tr>
    <tr>
      <td class="paramName">Is transactional?</td>
      <td><xsl:value-of select="transactional"/></td>
    </tr>
    <tr>
      <td class="paramName">Maximum number of connections</td>
      <td><xsl:value-of select="maxCons"/></td>
    </tr>
    <tr>
      <td class="paramName">Maximum number of connections allowed above the maximum</td>
      <td><xsl:value-of select="maxOverflowConnections"/></td>
    </tr>
    <tr>
      <td class="paramName">Time to wait for a connection when all are used</td>
      <td><xsl:value-of select="connectionWaitTime"/> millis</td>
    </tr>
    <tr>
      <td class="paramName">Time for a connection to be idle before it is closed</td>
      <td><xsl:value-of select="maxIdleTime"/> millis</td>
    </tr>
    <tr>
      <td class="paramName">Maximum time a connection can remain active</td>
      <td><xsl:value-of select="maxActiveTime"/> millis</td>
    </tr>
    <xsl:if test="pingTable">
    <tr>
      <td class="paramName">Validate connections on reuse?</td>
      <td><xsl:value-of select="pingOnReuse"/></td>
    </tr>
    <tr>
      <td class="paramName">Validate connections while they are idle?</td>
      <td><xsl:value-of select="pingOnIdle"/></td>
    </tr>
    <tr>
      <td class="paramName">Interval for idle connections validation</td>
      <td><xsl:value-of select="pingInterval"/> millis</td>
    </tr>
    <tr>
      <td class="paramName">Table used for connection validation</td>
      <td><xsl:value-of select="pingTable"/></td>
    </tr>
    </xsl:if>
    <tr>
      <td class="paramName" style="padding-top: 10px">Total number of connections</td>
      <td style="padding-top: 10px"><xsl:value-of select="totalCons"/></td>
    </tr>
    <tr>
      <td class="paramName">Number of active connections</td>
      <td><xsl:value-of select="activeCons"/></td>
    </tr>
  </xsl:template>

  <xsl:template match="commonsDBCP">
    <tr>
      <td class="paramName">Pool type</td>
      <td>Apache Commons DBCP</td>
    </tr>
    <tr>
      <td class="paramName">Driver</td>
      <td><xsl:value-of select="driverClassName"/></td>
    </tr>
    <tr>
      <td class="paramName">Database URL</td>
      <td><xsl:value-of select="url"/></td>
    </tr>
    <tr>
      <td class="paramName">Database user name</td>
      <td><xsl:value-of select="username"/></td>
    </tr>
    <tr>
      <td class="paramName">Does auto-commit by default?</td>
      <td><xsl:value-of select="autoCommit"/></td>
    </tr>
    <tr>
      <td class="paramName">Set to read-only by default?</td>
      <td><xsl:value-of select="readOnly"/></td>
    </tr>
    <xsl:if test="txIsolation">
      <tr>
        <td class="paramName">Default TX isolation level</td>
        <td><xsl:value-of select="txIsolation"/></td>
      </tr>
    </xsl:if>
    <xsl:if test="catalog">
      <tr>
        <td class="paramName">Default database catalog</td>
        <td><xsl:value-of select="catalog"/></td>
      </tr>
    </xsl:if>
    <tr>
      <td class="paramName">Pool prepared statements?</td>
      <td><xsl:value-of select="poolPS"/></td>
    </tr>
    <xsl:if test="poolPS = 'true'">
      <tr>
        <td class="paramName">Maximum number of open statements</td>
        <xsl:choose>
          <xsl:when test="maxOpenPSs > 0">
            <td><xsl:value-of select="maxOpenPSs"/></td>
          </xsl:when>
          <xsl:otherwise>
            <td><i>no limit</i></td>
          </xsl:otherwise>
        </xsl:choose>
      </tr>
    </xsl:if>
    <tr>
      <td class="paramName">Validate connections on borrow?</td>
      <td><xsl:value-of select="testOnBorrow"/></td>
    </tr>
    <tr>
      <td class="paramName">Validate connections on return?</td>
      <td><xsl:value-of select="testOnReturn"/></td>
    </tr>
    <tr>
      <td class="paramName">Validate connections while they are idle?</td>
      <td><xsl:value-of select="testWhileIdle"/></td>
    </tr>
    <tr>
      <td class="paramName">Connection validation query</td>
      <xsl:choose>
        <xsl:when test="valQuery">
          <td><xsl:value-of select="valQuery"/></td>
        </xsl:when>
        <xsl:otherwise>
          <td><i>no query defined</i></td>
        </xsl:otherwise>
      </xsl:choose>
    </tr>
    <tr>
      <td class="paramName">Maximum number of active connections</td>
      <xsl:choose>
        <xsl:when test="maxActive > 0">
          <td><xsl:value-of select="maxActive"/></td>
        </xsl:when>
        <xsl:otherwise>
          <td><i>no limit</i></td>
        </xsl:otherwise>
      </xsl:choose>
    </tr>
    <tr>
      <td class="paramName">Maximum wait for a connection</td>
      <xsl:choose>
        <xsl:when test="maxWait >= 0">
      <td><xsl:value-of select="maxWait"/> millis</td>
        </xsl:when>
        <xsl:otherwise>
          <td><i>wait indefinitely</i></td>
        </xsl:otherwise>
      </xsl:choose>
    </tr>
    <tr>
      <td class="paramName">Maximum number of idle connections</td>
      <xsl:choose>
        <xsl:when test="maxIdle >= 0">
      <td><xsl:value-of select="maxIdle"/></td>
        </xsl:when>
        <xsl:otherwise>
          <td><i>no limit</i></td>
        </xsl:otherwise>
      </xsl:choose>
    </tr>
    <tr>
      <td class="paramName">Minimum number of idle connections</td>
      <xsl:choose>
        <xsl:when test="minIdle > 0">
      <td><xsl:value-of select="minIdle"/></td>
        </xsl:when>
        <xsl:otherwise>
          <td><i>none</i></td>
        </xsl:otherwise>
      </xsl:choose>
    </tr>
    <tr>
      <td class="paramName">Time between idle connection eviction runs</td>
      <xsl:choose>
        <xsl:when test="timeBetweenEvictionRuns >= 0">
      <td><xsl:value-of select="timeBetweenEvictionRuns"/> millis</td>
        </xsl:when>
        <xsl:otherwise>
          <td><i>no eviction</i></td>
        </xsl:otherwise>
      </xsl:choose>
    </tr>
    <xsl:if test="timeBetweenEvictionRuns >= 0">
    <tr>
      <td class="paramName">Tests per eviction run</td>
      <td><xsl:value-of select="testsPerEvictionRun"/></td>
    </tr>
    <tr>
      <td class="paramName">Minimum time a connection may be idle</td>
      <td><xsl:value-of select="minEvictableIdleTime"/> millis</td>
    </tr>
    </xsl:if>
    <tr>
      <td class="paramName" style="padding-top: 10px">Number of active connections</td>
      <td style="padding-top: 10px"><xsl:value-of select="numActive"/></td>
    </tr>
    <tr>
      <td class="paramName">Number of idle connections</td>
      <td><xsl:value-of select="numIdle"/></td>
    </tr>
  </xsl:template>

</xsl:stylesheet>
