<!--
  - Stylesheet for JVM Info page.
  -
  - author Lev Himmelfarb
  - version $Id: jvminfo.xsl,v 1.4 2004/04/23 17:49:55 levahim Exp $
 -->

<xsl:stylesheet
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  version="1.0">

  <xsl:output method="html" encoding="ISO-8859-1"/>

  <xsl:template match="/">
    <html>
      <head>
        <link rel="stylesheet" type="text/css" href="cb2-admin?disp=css"/>
      </head>
      <body class="content">
        <xsl:apply-templates/>
      </body>
    </html>
  </xsl:template>

  <xsl:template match="stats">
    <xsl:apply-templates select="jvmInfo"/>
    <xsl:apply-templates select="impls"/>
    <xsl:apply-templates select="threads"/>
  </xsl:template>

  <xsl:template match="jvmInfo">
    <p><table class="params">
      <caption>General JVM Information</caption>
      <tr>
        <th>parameter</th>
        <th>value</th>
      </tr>
      <tr>
        <td class="paramName">Available processors</td>
        <td><xsl:value-of select="availProcs"/></td>
      </tr>
      <tr>
        <td class="paramName">Total amount of memory</td>
        <td><xsl:value-of select="totalMemory"/></td>
      </tr>
      <tr>
        <td class="paramName">Amount of free memory</td>
        <td><xsl:value-of select="freeMemory"/></td>
      </tr>
      <tr>
      	<td class="paramName">Running on host</td>
      	<xsl:choose>
      	  <xsl:when test="host">
      	  	<td><xsl:value-of select="host"/></td>
      	  </xsl:when>
      	  <xsl:otherwise>
      	  	<td><i>not available</i></td>
      	  </xsl:otherwise>
      	</xsl:choose>
      </tr>
    </table></p>
  </xsl:template>

  <xsl:template match="impls">
    <p><table class="params">
      <caption>Implementations</caption>
      <tr>
        <th>name</th>
        <th>class</th>
      </tr>
      <tr>
        <td class="paramName">JAXP DocumentBuilderFactory</td>
        <td><xsl:value-of select="dbfClass"/></td>
      </tr>
      <tr>
        <td class="paramName">JAXP DocumentBuilder</td>
        <td><xsl:value-of select="dbClass"/></td>
      </tr>
      <tr>
        <td class="paramName">DOM Implementation</td>
        <td><xsl:value-of select="domImplClass"/></td>
      </tr>
    </table></p>
  </xsl:template>

  <xsl:template match="threads">
    <p><table class="params">
      <caption>Threads</caption>
      <xsl:choose>
        <xsl:when test="count(thread) > 0">
          <tr>
            <th>name</th>
            <th>group name</th>
            <th>priority</th>
            <th>daemon?</th>
          </tr>
          <xsl:apply-templates/>
        </xsl:when>
        <xsl:otherwise>
          <tr>
            <td>Information about threads is unavailable</td>
          </tr>
        </xsl:otherwise>
      </xsl:choose>
    </table></p>
  </xsl:template>

  <xsl:template match="thread">
    <tr>
      <td><xsl:value-of select="name"/></td>
      <td><xsl:value-of select="group"/></td>
      <td><xsl:value-of select="priority"/></td>
      <td><xsl:value-of select="daemon"/></td>
    </tr>
  </xsl:template>

</xsl:stylesheet>
