<!--
  - Stylesheet for DAO Query Statistics page.
  -
  - author Lev Himmelfarb
  - version $Id: queries.xsl,v 1.3 2003/08/13 13:16:28 levahim Exp $
 -->

<xsl:stylesheet
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  version="1.0">

  <xsl:output method="html" encoding="ISO-8859-1"/>

  <xsl:param name="sortBy"/>

  <xsl:template match="/">
    <html>
      <head>
        <link rel="stylesheet" type="text/css" href="cb2-admin?disp=css"/>
      </head>
      <script type="text/javascript">
        function popup(dsName, n) {

            window.open("cb2-admin?disp=info&amp;ss=blMgr&amp;name=queryText&amp;dsName=" + escape(dsName) + "&amp;n=" + escape(n),
                        "queryTextPopup",
                        "width=500, height=400, menubar=no, toolbar=no, resizable=yes, scrollbars=yes");
        }
      </script>
      <body class="content">
        <xsl:apply-templates/>
      </body>
    </html>
  </xsl:template>

  <xsl:template match="stats">
    <xsl:apply-templates select="daos"/>
  </xsl:template>

  <xsl:template match="daos">
    <p><table class="params">
    <caption>Query Statistics</caption>
      <tr>
        <th><a href="cb2-admin?disp=info&amp;ss=blMgr&amp;name=queries&amp;sortBy=name" class="headerLink">name</a></th>
        <th>text</th>
        <th><a href="cb2-admin?disp=info&amp;ss=blMgr&amp;name=queries&amp;sortBy=execs" class="headerLink">execs</a></th>
        <th><a href="cb2-admin?disp=info&amp;ss=blMgr&amp;name=queries&amp;sortBy=time" class="headerLink">time</a></th>
        <th><a href="cb2-admin?disp=info&amp;ss=blMgr&amp;name=queries&amp;sortBy=min" class="headerLink">min (ms)</a></th>
        <th><a href="cb2-admin?disp=info&amp;ss=blMgr&amp;name=queries&amp;sortBy=avg" class="headerLink">avg (ms)</a></th>
        <th><a href="cb2-admin?disp=info&amp;ss=blMgr&amp;name=queries&amp;sortBy=max" class="headerLink">max (ms)</a></th>
      </tr>
      <xsl:apply-templates/>
    </table></p>
  </xsl:template>

  <xsl:template match="dao">
    <tr>
      <td colspan="6" class="sectionTitle">DataSource: <xsl:value-of select="@name"/></td>
    </tr>
    <xsl:apply-templates/>
  </xsl:template>

  <xsl:template match="daostats">
    <xsl:choose>
      <xsl:when test="$sortBy='execs'">
        <xsl:apply-templates>
          <xsl:sort select="nExecs" data-type="number" order="descending"/>
        </xsl:apply-templates>
      </xsl:when>
      <xsl:when test="$sortBy='time'">
        <xsl:apply-templates>
          <xsl:sort select="timeMillis" data-type="number" order="descending"/>
        </xsl:apply-templates>
      </xsl:when>
      <xsl:when test="$sortBy='min'">
        <xsl:apply-templates>
          <xsl:sort select="execTimeMin + procTimeMin" data-type="number" order="descending"/>
        </xsl:apply-templates>
      </xsl:when>
      <xsl:when test="$sortBy='avg'">
        <xsl:apply-templates>
          <xsl:sort select="execTimeAvg + procTimeAvg" data-type="number" order="descending"/>
        </xsl:apply-templates>
      </xsl:when>
      <xsl:when test="$sortBy='max'">
        <xsl:apply-templates>
          <xsl:sort select="execTimeMax + procTimeMax" data-type="number" order="descending"/>
        </xsl:apply-templates>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates>
          <xsl:sort select="name"/>
        </xsl:apply-templates>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="query">
    <tr>
      <xsl:choose>
      	<xsl:when test="count(name) > 0">
          <td><xsl:value-of select="name"/></td>
        </xsl:when>
        <xsl:otherwise>
          <td><span class="special">(unnamed)</span></td>
        </xsl:otherwise>
      </xsl:choose>
      <td><a><xsl:attribute name="href">javascript:popup('<xsl:value-of select="../../@name"/>', '<xsl:value-of select="@n"/>')</xsl:attribute>[see]</a></td>
      <td align="right"><xsl:value-of select="nExecs"/></td>
      <td align="right"><xsl:value-of select="time"/></td>
      <xsl:choose>
        <xsl:when test="procTimeMin >= 0">
          <td align="right"><xsl:value-of select="execTimeMin"/>+<xsl:value-of select="procTimeMin"/>:<xsl:value-of select="execTimeMin + procTimeMin"/></td>
        </xsl:when>
        <xsl:otherwise>
          <td align="right"><xsl:value-of select="execTimeMin"/></td>
        </xsl:otherwise>
      </xsl:choose>
      <xsl:choose>
        <xsl:when test="procTimeAvg >= 0">
          <td align="right"><xsl:value-of select="execTimeAvg"/>+<xsl:value-of select="procTimeAvg"/>:<xsl:value-of select="execTimeAvg + procTimeAvg"/></td>
        </xsl:when>
        <xsl:otherwise>
          <td align="right"><xsl:value-of select="execTimeAvg"/></td>
        </xsl:otherwise>
      </xsl:choose>
      <xsl:choose>
        <xsl:when test="procTimeMax >= 0">
          <td align="right"><xsl:value-of select="execTimeMax"/>+<xsl:value-of select="procTimeMax"/>:<xsl:value-of select="execTimeMax + procTimeMax"/></td>
        </xsl:when>
        <xsl:otherwise>
          <td align="right"><xsl:value-of select="execTimeMax"/></td>
        </xsl:otherwise>
      </xsl:choose>
    </tr>
  </xsl:template>

</xsl:stylesheet>
