<!--
  - Stylesheet for Servlet User Sessions page.
  -
  - author Lev Himmelfarb
  - version $Id: usersessions.xsl,v 1.3 2003/07/20 16:04:19 levahim Exp $
 -->

<xsl:stylesheet
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  version="1.0">

  <xsl:output method="html" encoding="ISO-8859-1"/>

  <xsl:param name="timezone"/>
  <xsl:param name="sortBy"/>

  <xsl:template match="/">
    <html>
      <head>
        <link rel="stylesheet" type="text/css" href="cb2-admin?disp=css"/>
      </head>
      <script type="text/javascript">
        function errorsPopup(sessionId) {

            window.open("cb2-admin?disp=info&amp;ss=ctrlr&amp;name=lastErrors&amp;sessionId=" + escape(sessionId),
                        "lastErrorsPopup",
                        "width=500, height=400, menubar=no, toolbar=no, resizable=yes, scrollbars=yes");
        }
      </script>
      <body class="content">
        <xsl:apply-templates/>
      </body>
    </html>
  </xsl:template>

  <xsl:template match="stats">
    <xsl:apply-templates select="sessions"/>
  </xsl:template>

  <xsl:template match="sessions">
    <p><table class="params">
      <caption>User Sessions<sup>*</sup></caption>
      <xsl:choose>
        <xsl:when test="count(session) > 0">
          <tr>
            <th>session id</th>
            <th><a href="cb2-admin?disp=info&amp;ss=ctrlr&amp;name=userSessions&amp;sortBy=createdOn" class="headerLink">created on</a></th>
            <th>auth'd user</th>
            <th><a href="cb2-admin?disp=info&amp;ss=ctrlr&amp;name=userSessions&amp;sortBy=authedOn" class="headerLink">auth'd on</a></th>
            <th><a href="cb2-admin?disp=info&amp;ss=ctrlr&amp;name=userSessions&amp;sortBy=nActs" class="headerLink">acts</a></th>
            <th><a href="cb2-admin?disp=info&amp;ss=ctrlr&amp;name=userSessions&amp;sortBy=nErrors" class="headerLink">errs</a></th>
            <th>last 6 hrs</th>
          </tr>
          <xsl:choose>
          	<xsl:when test="$sortBy='authedOn'">
              <xsl:apply-templates>
                <xsl:sort select="authedOn" order="descending"/>
              </xsl:apply-templates>
            </xsl:when>
          	<xsl:when test="$sortBy='nActs'">
              <xsl:apply-templates>
                <xsl:sort select="nActs" data-type="number" order="descending"/>
              </xsl:apply-templates>
            </xsl:when>
          	<xsl:when test="$sortBy='nErrors'">
              <xsl:apply-templates>
                <xsl:sort select="nErrors" data-type="number" order="descending"/>
              </xsl:apply-templates>
            </xsl:when>
          	<xsl:otherwise>
              <xsl:apply-templates>
                <xsl:sort select="createdOn" order="descending"/>
              </xsl:apply-templates>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:when>
        <xsl:otherwise>
          <tr>
            <td>No user sessions</td>
          </tr>
        </xsl:otherwise>
      </xsl:choose>
    </table></p>
    <div class="comment"><sup>*</sup> All timestamps are in <xsl:value-of select="$timezone"/></div>
  </xsl:template>

  <xsl:template match="session">
    <tr>
      <td><xsl:value-of select="@id"/></td>
      <td><xsl:value-of select="createdOn"/></td>
      <xsl:choose>
        <xsl:when test="user">
          <td><xsl:value-of select="user"/></td>
          <td><xsl:value-of select="authedOn"/></td>
        </xsl:when>
        <xsl:otherwise>
          <td>-</td>
          <td>-</td>
        </xsl:otherwise>
      </xsl:choose>
      <td align="right"><xsl:value-of select="nActs"/></td>
      <xsl:choose>
      	<xsl:when test="nErrors > 0">
          <td align="right"><a><xsl:attribute name="href">javascript:errorsPopup('<xsl:value-of select="@id"/>')</xsl:attribute><xsl:value-of select="nErrors"/></a></td>
        </xsl:when>
        <xsl:otherwise>
          <td align="right">0</td>
        </xsl:otherwise>
      </xsl:choose>
      <td><img width="62" height="14"><xsl:attribute name="src">cb2-admin?disp=pic&amp;ss=ctrlr&amp;name=sessionActivity_<xsl:value-of select="blSessionId"/>&amp;size=S&amp;ind=0&amp;maxSample=<xsl:value-of select="../../maxSamples/actMaxSample[@ind=0]"/></xsl:attribute></img></td>
    </tr>
  </xsl:template>

</xsl:stylesheet>
