package com.boylesoftware.cb2.bcmproviders.http;

import java.io.PrintWriter;
import java.io.IOException;
import java.util.Properties;
import javax.servlet.ServletException;
import javax.servlet.UnavailableException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.logging.Log;

import com.boylesoftware.cb2.ApplicationContext;
import com.boylesoftware.cb2.ApplicationException;
import com.boylesoftware.cb2.presentation.servlet.CB2Application;
import com.boylesoftware.cb2.presentation.servlet.CB2PlugIn;
import com.boylesoftware.cb2.util.HttpResponseUtils;
import com.boylesoftware.cb2.util.CodeUtils;


/**
 * The reciever servlet for <code>HttpBCMProvider</code> BCM provider
 * implementation. This servlet must be deployed on every member of the
 * cluster if you use <code>HttpBCMProvider</code> for broadcast messaging.
 * Note, that this servlet must be loaded <strong>after</strong> the main
 * Struts controller servlet.
 *
 * <p>This class logs messages under "com.boylesoftware.cb2.HTPRCV"
 * channel.
 *
 * @author Lev Himmelfarb
 * @version $Id: ReceiverServlet.java,v 1.5 2004/10/11 18:17:36 levahim Exp $
 *
 * @see HttpBCMProvider
 */
public final class ReceiverServlet
    extends HttpServlet {

    /**
     * Subsystem name for the logger.
     */
    private final static String LOG_SUBSYS = "com.boylesoftware.cb2.HTPRCV";

    /**
     * Our application context.
     */
    private ApplicationContext appCtx;

    /**
     * Log to be used for debug messages.
     */
    private Log log;


    /**
     * Initialize the servlet.
     *
     * @throws UnavailableException if the servlet could not be initialized
     * and was not deployed.
     */
    public void init()
        throws UnavailableException {

        CB2Application app = CB2PlugIn.getApplication(this.getServletContext());
        if(app == null)
            throw new UnavailableException("The ControllerServlet is not available, probably the action servlet is not deployed.");
        this.appCtx = app.getApplicationContext();
        this.log = this.appCtx.getLog(LOG_SUBSYS);
    }


    /**
     * Handle a <code>GET</code> request.
     *
     * @param request the HTTP request.
     * @param response the HTTP response.
     *
     * @throws ServletException if an unexpected error happens.
     * @throws IOException if an input/output error happens.
     */
    protected void doGet(HttpServletRequest request,
                         HttpServletResponse response)
        throws ServletException, IOException {

        // read the properties
        Properties props = this.appCtx.getProperties();
        String password = props.getProperty("com.boylesoftware.cb2.broadcastMessaging.http.password");
        if(password == null) {
            this.log.error("The com.boylesoftware.cb2.broadcastMessaging.http.password property is not defined.");
            throw new ServletException("The com.boylesoftware.cb2.broadcastMessaging.http.password property is not defined.");
        }

        // log the request
        if(this.log.isDebugEnabled()) {
            this.log.debug("processing request [" + request.getRequestURL() +
                           "] from " + request.getRemoteAddr());
        }

        // set the response params
        response.setContentType("text/plain; charset=ISO-8859-1");
        HttpResponseUtils.setNoCache(response);

        // get the out stream
        PrintWriter out = response.getWriter();

        // check the auth info
        if(!password.equals(request.getParameter("password"))) {
            this.log.error("Invalid authentication info, the query string was [" +
                           request.getQueryString() + "]");
            out.print("error:auth");
            return;
        }

        // get the channel
        String channelName = request.getParameter("channel");
        if((channelName == null) || (channelName.length() == 0)) {
            this.log.error("No channel parameter, the query string was [" +
                           request.getQueryString() + "]");
            out.print("error:param");
            return;
        }

        // deliver the message to the appropriate terminal
        try {
            Object param = null;
            String paramS = request.getParameter("param");
            if(paramS != null)
                param = CodeUtils.stringToObject(paramS);

            this.appCtx.processBCMMessage(channelName,
                                          request.getRemoteAddr(),
                                          (java.io.Serializable)param);

        } catch(ClassNotFoundException e) {
            this.log.error("Unknown message parameter class.", e);
            out.print("error:param");
            return;

        } catch(ApplicationException e) {
            this.log.error("Exception processing the message in the terminal.", e);
            out.print("error:exception");
            return;
        }

        // done
        out.print("ok");
    }
}
