package com.boylesoftware.cb2.bcmproviders.local;

import java.io.Serializable;

import com.boylesoftware.cb2.ApplicationContext;
import com.boylesoftware.cb2.ApplicationException;
import com.boylesoftware.cb2.BroadcastMessagingProvider;


/**
 * Simple stub-like BCM provider, which does not do any actual broadcasting.
 * Instead, it just delivers messages locally, so the "cluster" consists of
 * only one instance - this one.
 *
 * @author Lev Himmelfarb
 * @version $Id: LocalProvider.java,v 1.2 2004/04/08 18:32:23 levahim Exp $
 */
public class LocalProvider
    implements BroadcastMessagingProvider {

    /**
     * Our application context.
     */
    private ApplicationContext appCtx;


    /**
     * Initialize the provider.
     *
     * @param appCtx our application context.
     */
    public void init(ApplicationContext appCtx) {

        this.appCtx = appCtx;
    }

    /**
     * Destroy the instance.
     */
    public void destroy() {

        this.appCtx = null;
    }

    /**
     * Deliver a message to all local terminals registered for the channel.
     * In fact this method just calls <code>processBCMMessage</code> on the
     * application context.
     *
     * @param channelName BCM channel name.
     * @param messageParam optional message parameter, may be
     * <code>null</code>.
     */
    public void broadcastMessage(String channelName, Serializable messageParam) {

        try {

            this.appCtx.processBCMMessage(channelName, "local", messageParam);

        } catch(ApplicationException e) {
            this.appCtx.getLog(LOG_SUBSYS).error("got error delivering BCM message to local terminals", e);
        }
    }
}
