package com.boylesoftware.cb2.bcmproviders.sockethub;

import java.io.Serializable;
import java.io.ByteArrayOutputStream;
import java.io.ByteArrayInputStream;
import java.io.ObjectOutputStream;
import java.io.ObjectInputStream;
import java.io.IOException;


/**
 * Message object used for communication with the hub.
 *
 * @author Lev Himmelfarb
 * @version $Id: Message.java,v 1.4 2003/10/24 21:09:47 levahim Exp $
 */
class Message
    implements Serializable {

    /**
     * Regular message.
     */
    public static final int TYPE_REGULAR = 0;

    /**
     * Shutdown the hub.
     */
    public static final int TYPE_SHUTDOWN = 1;

    /**
     * Open session on this client connection.
     */
    public static final int TYPE_OPEN = 2;

    /**
     * Terminate this client connection.
     */
    public static final int TYPE_CLOSE = 3;

    /**
     * Ignore the message.
     */
    public static final int TYPE_NOP = 4;

    /**
     * Special "get status" message.
     */
    public static final int TYPE_STATUS = 5;

    /**
     * Special "ping" message.
     */
    public static final int TYPE_PING = 6;


    /**
     * Type of the message, one of <code>TYPE_xxx</code> constants.
     */
    public int type;

    /**
     * IP address of the source of the message.
     */
    public String source;

    /**
     * Name of the BC channel.
     */
    public String channelName;

    /**
     * Serialized optional message parameter. May be <code>null</code>.
     * We keep in the serialized form so the JVM running the hub does not
     * need all the possible message parameter classes in its class path.
     */
    public byte [] messageParam;


    /**
     * Restores the message parameter from the serialized form.
     *
     * @return the deserialized message parameter.
     *
     * @throws IOException if an error happens deserializing the message
     * parameter.
     * @throws ClassNotFoundException if the message parameter's class
     * is not available to the JVM.
     */
    public Serializable getMessageParam()
        throws IOException, ClassNotFoundException {

        if(this.messageParam == null)
            return null;

        Serializable res;
        ObjectInputStream ois = new ObjectInputStream(new ByteArrayInputStream(this.messageParam));
        res = (Serializable)ois.readObject();
        ois.close();

        return res;
    }

    /**
     * Serializes the specified message parameter and saves it in the
     * <code>messageParam</code> field.
     *
     * @param messageParam the object to serialize.
     *
     * @throws IOException if an error happens serializing the object.
     */
    public void setMessageParam(Serializable messageParam)
        throws IOException {

        if(messageParam == null) {
            this.messageParam = null;
            return;
        }

        ByteArrayOutputStream baos = new ByteArrayOutputStream(4096);
        ObjectOutputStream oos = new ObjectOutputStream(baos);
        oos.writeObject(messageParam);
        oos.flush();
        this.messageParam = baos.toByteArray();
        oos.close();
    }
}
