package com.boylesoftware.cb2.commons.user;

import java.util.EventListener;

import com.boylesoftware.cb2.BLException;


/**
 * Interface for BLOs that want to listen for user session state
 * changes. Usually the UserBLO, or derived from it custom classes,
 * emit a UserSessionStateEvent whenever the user session state
 * changes, for example the user logs in or logs out the
 * application. Your BLO can implement this interface and register
 * with UserBLO to receive notifications.
 *
 * @author Lev Himmelfarb
 * @version $Id: UserSessionStateListener.java,v 1.1 2003/04/22 17:34:18 levahim Exp $
 * @see UserSessionStateEvent
 * @see UserBLO
 */
public interface UserSessionStateListener
    extends EventListener {

    /**
     * Called whenever a user logged in to the application.
     */
    public void userLoggedIn(UserSessionStateEvent usse)
        throws BLException;

    /**
     * Called whenever a user logged out from the application.
     */
    public void userLoggedOut(UserSessionStateEvent usse)
        throws BLException;
}
