package com.boylesoftware.cb2.presentation.servlet;


/**
 * Descriptor of a page component.
 *
 * @author Lev Himmelfarb
 * @version $Id: ComponentDesc.java,v 1.2 2004/10/11 18:17:36 levahim Exp $
 */
final class ComponentDesc {

    /**
     * Component's name.
     */
    final String name;

    /**
     * Context relative URL for the component's JSP.
     */
    final String src;

    /**
     * Ordered list of descriptors of global presentation elements on which
     * this component depends. The list is filtered and contains no duplicates.
     */
    final PresentationElementDesc [] dependsOn;

    /**
     * Ordered list of descriptors of the component's local presentation
     * elements.
     */
    final PresentationElementDesc [] pelements;


    /**
     * Constructs a component descriptor.
     *
     * @param name the component's name.
     * @param src context relative URL of the component's JSP.
     * @param dependsOn ordered list of descriptors of global
     * presentation elements on which this component depends. The list
     * is filtered and contains no duplicates.
     * @param pelements ordered list of descriptors of the component's
     * local presentation elements.
     */
    public ComponentDesc(String name,
                         String src,
                         PresentationElementDesc [] dependsOn,
                         PresentationElementDesc [] pelements) {

        this.name = name;
        this.src = src;
        this.dependsOn = dependsOn;
        this.pelements = pelements;
    }
}
