package com.boylesoftware.cb2.presentation.servlet;


/**
 * Descriptor of a form bean reference.
 *
 * @author Lev Himmelfarb
 * @version $Id: FormBeanRefDesc.java,v 1.2 2004/05/20 19:19:52 levahim Exp $
 */
final class FormBeanRefDesc {

    // Form bean scopes
    static final int SCOPE_REQUEST = 1;
    static final int SCOPE_SESSION = 2;


    /**
     * The reference name used by pelements' "inputForm" attributes.
     */
    final String name;

    /**
     * The corresponding form bean name as defined in Struts.
     */
    final String formBeanName;

    /**
     * Form bean implementation class or <code>null</code>.
     */
    final Class formBeanClass;

    /**
     * The form bean's scope, one of <code>SCOPE_xxx</code> constants.
     */
    final int scope;


    /**
     * Creates a form bean reference descriptor.
     *
     * @param name the reference name.
     * @param formBeanName the form bean name.
     * @param formBeanClass the form bean class or <code>null</code>.
     * @param scope the form bean scope.
     */
    FormBeanRefDesc(String name,
                    String formBeanName,
                    Class formBeanClass,
                    int scope) {

        this.name = name;
        this.formBeanName = formBeanName;
        this.formBeanClass = formBeanClass;
        this.scope = scope;
    }
}
