package com.boylesoftware.cb2.presentation.servlet;

import javax.servlet.ServletException;

import com.boylesoftware.cb2.BLException;


/**
 * CB2 presentation elements implement this interface.
 *
 * @author Lev Himmelfarb
 * @version $Id: PresentationElement.java,v 1.2 2003/07/20 16:04:19 levahim Exp $
 */
public interface PresentationElement {

    /**
     * Initializes the presentation element. This method is called by
     * the framework on presentation elements before they start being
     * used from the JSPs. If a presentation element is included in a
     * transactional page then this method is called from within a
     * database transaction. Multiple presentation elements a
     * initialized in a single transaction if they are included in one
     * page. When this mathod is called all configured presentation
     * element parameters are already set.
     *
     * @param actionCtx the action context.
     *
     * @throws BLException if an error happened in the business level.
     * @throws ServletException if an error happened during element
     * initialization.
     */
    public void init(ActionContext actionCtx)
        throws BLException, ServletException;

    /**
     * Resets fields of the presentation element to their default values.
     * The exact moment when the system calls this method is undefined,
     * however there is a guarantee that is will be called before any
     * <code>init</code> method call, which also means that it is not
     * necessary to set default values to the fields in the constructor.
     *
     * <p>This method is especially usefull for optional input parameters.
     * If an optional parameter (the <code>required</code> attribute is set
     * to <code>false</code> in the parameter descriptor) is not present
     * in the specified scope, the system does not do anything, it does
     * not call any setter and leaves the respective bean's property
     * untouched. Therefore, setting a value in the <code>reset</code> method
     * is the only way to set the default value for an optional input
     * parameter.
     */
    public void reset();
}
