package com.boylesoftware.cb2.util;

import java.io.IOException;
import javax.servlet.ServletException;

import com.boylesoftware.cb2.BLException;


/**
 * Collection of static utility methods to work with Java exceptions.
 *
 * @author Lev Himmelfarb
 * @version $Id: ExceptionUtils.java,v 1.1 2004/04/08 18:32:23 levahim Exp $
 */
public final class ExceptionUtils {

    /**
     * Takes a throwable and rethrows it wrapping it into a
     * <code>BLException</code> if necessary. It wraps the throwable
     * into a <code>BLException</code> if it is not already an instance of
     * <code>BLException</code>, nor <code>RuntimeException</code> and nor
     * <code>Error</code>, in which case it rethrows the throwable as it is.
     *
     * @param t the throwable.
     * @param message error message to set in the <code>BLException</code>
     * if the original throwable needs to be wrapped.
     *
     * @throws BLException if the throwable is not a
     * <code>RuntimeException</code> nor <code>Error</code>. If the throwable
     * is already an instance of <code>BLException</code> the exception
     * thrown by this method is exactly the same instance.
     */
    public static void rethrowBLException(Throwable t,
                                          String message)
        throws BLException {

        if(t instanceof BLException)
            throw (BLException)t;
        else if(t instanceof RuntimeException)
            throw (RuntimeException)t;
        else if(t instanceof Error)
            throw (Error)t;
        else
            throw new BLException(message, t);
    }

    /**
     * Takes a throwable and rethrows it wrapping it into a
     * <code>ServletException</code> if necessary. It wraps the throwable
     * into a <code>ServletException</code> if it is not already an instance of
     * <code>ServletException</code>, nor <code>IOException</code>, nor
     * <code>RuntimeException</code> and nor <code>Error</code>, in which case
     * it rethrows the throwable as it is.
     *
     * @param t the throwable.
     * @param message error message to set in the <code>ServletException</code>
     * if the original throwable needs to be wrapped.
     *
     * @throws ServletException if the throwable is not a
     * <code>RuntimeException</code>, nor <code>Error</code>, nor
     * <code>IOException</code>. If the throwable is already an instance of
     * <code>ServletException</code> the exception thrown by this method is
     * exactly the same instance.
     * @throws IOException if the throwable is a <code>IOException</code>
     * instance already.
     */
    public static void rethrowServletException(Throwable t,
                                               String message)
        throws ServletException, IOException {

        if(t instanceof ServletException)
            throw (ServletException)t;
        if(t instanceof IOException)
            throw (IOException)t;
        else if(t instanceof RuntimeException)
            throw (RuntimeException)t;
        else if(t instanceof Error)
            throw (Error)t;
        else
            throw new ServletException(message, t);
    }
}
