package com.boylesoftware.cb2.util;

import java.util.Map;
import java.util.HashMap;
import org.xml.sax.EntityResolver;
import org.xml.sax.InputSource;


/**
 * This entity resolver allows to access local copies of DTDs referred
 * from XML configuration files. The DTDs are stored in a class
 * resources.
 *
 * @author Lev Himmelfarb
 * @version $Id: LocalResourceEntityResolver.java,v 1.1 2003/04/22 17:34:18 levahim Exp $
 */
public class LocalResourceEntityResolver
    implements EntityResolver {

    /**
     * The class, which resources keep the DTDs.
     */
    private final Class baseClass;

    /**
     * List of entities we've got local DTDs for. The keys are entity
     * public identifiers (objects of <code>String</code>) and the
     * values are resource URLs (objects of <code>String</code>).
     */
    private final Map knownEntities;


    /**
     * Constructs a resolver.
     *
     * @param baseClass class. which has the DTDs as its resources.
     * @param entities list of known entities and their local resource
     * paths. The even elements of the array are entity public
     * identifiers, the odd elements are DTD URLs.
     */
    public LocalResourceEntityResolver(Class baseClass, String [] entities) {

        this.baseClass = baseClass;
        this.knownEntities = new HashMap(entities.length / 2);
        for(int i = 0; i < entities.length; i += 2) {
            this.knownEntities.put(entities[i], entities[i + 1]);
        }
    }


    /**
     * The interface method implementation.
     *
     * @param publicId public id of the entity to resolve.
     * @param systemId system id of the entity to resolve.
     *
     * @return input source for the entity or <code>null</code> if the
     * entity is unknown to this resolver and the system id should be
     * used to resolve it.
     */
    public InputSource resolveEntity(String publicId, String systemId) {

        if(publicId == null)
            return null;

        String resPath = (String)this.knownEntities.get(publicId);
        if(resPath == null)
            return null;

        InputSource res = new InputSource(this.baseClass.getResource(resPath).toExternalForm());
        res.setPublicId(publicId);
        res.setEncoding("ISO-8859-1");

        return res;
    }
}
