package com.boylesoftware.cb2.util;

import org.w3c.dom.Element;
import org.w3c.dom.Node;


/**
 * A collection of utility functions that help to work with XML.
 *
 * @author Lev Himmelfarb
 * @version $Id: XMLUtils.java,v 1.3 2003/08/29 13:08:53 levahim Exp $
 */
public final class XMLUtils {

    /**
     * Retrieves text body of an XML node.
     *
     * @param node the XML node to fetch text content from.
     *
     * @return text contained in the specified node or
     * <code>null</code> if there is no text content in the node.
     */
    public static String getXMLNodeText(Node node) {

        StringBuffer res = new StringBuffer();
        boolean hasText = false;

        for(Node nestedNode = node.getFirstChild();
            nestedNode != null;
            nestedNode = nestedNode.getNextSibling())
            if((nestedNode.getNodeType() == Node.TEXT_NODE) ||
               (nestedNode.getNodeType() == Node.CDATA_SECTION_NODE)) {
                res.append(nestedNode.getNodeValue());
                hasText = true;
            }

        return (hasText ? res.toString() : null);
    }

    /**
     * Retrieves text body of an XML element's subnode.
     *
     * @param element the XML element to look for the subnode in.
     * @param subelementName name of the nested node.
     *
     * @return text contained in the specified subnode or
     * <code>null</code> if there is no such a subnode or there is no
     * text content in it.
     */
    public static String getXMLSubelementText(Element element, String subelementName) {

        Node node = element.getElementsByTagName(subelementName).item(0);

        return (node != null ? getXMLNodeText(node) : null);
    }
}
