package com.boylesoftware.cb2.util.pool;


/**
 * Simple pooled object factory implementation, which creates
 * instances of a specified during initialization class using its
 * default constructor.
 *
 * @author Lev Himmelfarb
 * @version $Id: SimplePooledObjectFactory.java,v 1.3 2003/07/23 22:18:08 levahim Exp $
 */
public class SimplePooledObjectFactory
    extends PooledObjectFactoryAdapter {

    /**
     * The objects' class.
     */
    protected final Class theClass;


    /**
     * Constructs a factory.
     *
     * @param theClass class of the objects this factory will be
     * instantiating.
     */
    public SimplePooledObjectFactory(Class theClass) {

        this.theClass = theClass;
    }


    /**
     * Instantiates an object for a pool.
     *
     * @return the new object instance.
     *
     * @throws RuntimeException if the object cannot be instantiated.
     */
    public Object createObject() {

        try {
            return this.theClass.newInstance();
        } catch(IllegalAccessException e) {
            throw new RuntimeException("Could not create an object instance.", e);
        } catch(InstantiationException e) {
            throw new RuntimeException("Could not create an object instance.", e);
        }
    }
}
